ref: 26f34fd59da1ce1885d4f2909c5d9ef9c1726944
parent: 730b66b6520f263af16f555d1d7be51205a8e51d
author: Brian Fitzgerald <[email protected]>
date: Thu Mar 22 18:11:35 EDT 2018
Fix two tests that are broken on Windows Put guards around TestPageBundlerCaptureSymlinks and TestPageBundlerSiteWitSymbolicLinksInContent so that they aren't run on Windows (they both use symbolic links and the Go library implementation requires administrator mode on Windows).
--- a/hugolib/page_bundler_test.go
+++ b/hugolib/page_bundler_test.go
@@ -308,6 +308,10 @@
}
func TestPageBundlerSiteWitSymbolicLinksInContent(t *testing.T) {
+ if runtime.GOOS == "windows" && os.Getenv("CI") == "" {
+ t.Skip("Skip TestPageBundlerSiteWitSymbolicLinksInContent as os.Symlink needs administrator rights on Windows")
+ }
+
assert := require.New(t)
ps, workDir := newTestBundleSymbolicSources(t)
cfg := ps.Cfg
--- a/hugolib/page_bundler_capture_test.go
+++ b/hugolib/page_bundler_capture_test.go
@@ -22,6 +22,7 @@
jww "github.com/spf13/jwalterweatherman"
+ "runtime"
"strings"
"sync"
"testing"
@@ -82,6 +83,10 @@
}
func TestPageBundlerCaptureSymlinks(t *testing.T) {
+ if runtime.GOOS == "windows" && os.Getenv("CI") == "" {
+ t.Skip("Skip TestPageBundlerCaptureSymlinks as os.Symlink needs administrator rights on Windows")
+ }
+
assert := require.New(t)
ps, workDir := newTestBundleSymbolicSources(t)
sourceSpec := source.NewSourceSpec(ps, ps.BaseFs.ContentFs)
@@ -92,7 +97,7 @@
assert.NoError(c.capture())
// Symlik back to content skipped to prevent infinite recursion.
assert.Equal(uint64(3), logger.LogCountForLevelsGreaterThanorEqualTo(jww.LevelWarn))
expected := `
@@ -92,7 +97,7 @@
assert.NoError(c.capture())
- // Symlik back to content skipped to prevent infinite recursion.
+ // Symlink back to content skipped to prevent infinite recursion.
assert.Equal(uint64(3), logger.LogCountForLevelsGreaterThanorEqualTo(jww.LevelWarn))
expected := `